@@ -43,7 +43,7 @@ from contextlib import contextmanager
 import pandas as pd
 import json
 from six import iteritems
-from spylon.common import _as_iterable
+from spylon.common import as_iterable
 
 log = logging.getLogger("spylon.spark.launcher")
 
@@ -349,7 +349,16 @@ class SparkConfiguration(object):
     _spark_launcher_arg_names = {
         'master', 'deploy-mode', 'jars', 'packages', 'exclude-packages', 'repositories', 'py-files', 'files',
         'properties-file', 'driver-memory', 'driver-java-options', 'driver-library-path', 'driver-class-path',
-        'driver-cores', 'executor-memory', 'proxy-user', 'verbose', 'executor-cores'
+        'driver-cores', 'executor-memory', 'proxy-user', 'verbose', 'executor-cores',
+        # Standalone and Mesos only
+        'total-executor-cores',
+        # YARN only
+        'driver-cores',
+        'queue',
+        'num-executors',
+        'archives',
+        'principal',
+        'keytab',
     }
     _spark_launcher_arg_sep = {'driver-java-options': ' ',
                                'driver-library-path': ':',
@@ -432,7 +441,7 @@ class SparkConfiguration(object):
         for key, val in self._spark_launcher_args.items():
             if val is None:
                 continue
-            val = list(_as_iterable(val))
+            val = list(as_iterable(val))
             if len(val):
                 if key in self._boolean_args:
                     cmd.append("--{key}".format(key=key))
@@ -452,17 +461,18 @@ class SparkConfiguration(object):
         spark_home = self.spark_home
         python_path = self._python_path
 
-        if _SPARK_INITIALIZED:
-            if spark_home == os.environ["SPARK_HOME"]:
-                # matches with already initialized
-                pass
+        if use_findspark:
+            if _SPARK_INITIALIZED:
+                if spark_home == os.environ["SPARK_HOME"]:
+                    # matches with already initialized
+                    pass
+                else:
+                    # findspark adds two path to the search path.
+                    sys.path.pop(0)
+                    sys.path.pop(0)
+                    findspark.init(spark_home=spark_home, edit_rc=False, edit_profile=False, python_path=python_path)
             else:
-                # findspark adds two path to the search path.
-                sys.path.pop(0)
-                sys.path.pop(0)
                 findspark.init(spark_home=spark_home, edit_rc=False, edit_profile=False, python_path=python_path)
-        else:
-            findspark.init(spark_home=spark_home, edit_rc=False, edit_profile=False, python_path=python_path)
 
         _SPARK_INITIALIZED = True
         self._set_environment_variables()
@@ -546,7 +556,7 @@ def with_spark_context(application_name, conf=None):
     Used within a context manager
     >>> with with_spark_context("MyApplication") as sc:
     ...     # Your Code here
-    ...
+    ...     pass
 
     """
     if conf is None:
@@ -575,7 +585,7 @@ def with_sql_context(application_name, conf=None):
     >>> with with_sql_context("MyApplication") as (sc, sql_context):
     ...     import pyspark
     ...     # Do stuff
-    ...     ...
+    ...     pass
 
     """
     if conf is None:
